==> BayesianFROC_0.1.1.tar.gz: BayesianFROC/R/fit_MRMC_test.R <==
#' @title  Fit and Draw the FROC models (curves)
#'
#'@inheritParams fit_Bayesian_FROC
#'@description  Fit and Draw the FROC models (curves).
#'
# sum(exp(rstan::extract(stan.MRMC)$lp__))/(10000-3000)
# devtools::use_package("base")# this will cause error, do not run!!
# devtools::use_package("rstan")
# devtools::use_package("knitr")
# devtools::use_package("readxl")
# devtools::use_package("openxlsx")
# devtools::use_package("xlsx")

# @importFrom base system.file
# devtools::document();help("fit_MRMC_test") # Confirm reflection



#' @export fit_MRMC_test

fit_MRMC_test<- function(
                      dataList,
                      DrawCurve = FALSE,
                      PreciseLogLikelihood = FALSE,
                      summary =TRUE,
                      mesh.for.drawing.curve=10000,
                      significantLevel = 0.7,
                      cha = 1,
                      war = floor(ite/5),
                      ite = 10000,
                      dig = 3,
                      see = 1234569){
 if(summary==TRUE){ viewdata(dataList )} # I do not know, but this code is the availble only in the last part.

   # war <- 5000 ;ite <- 10000;see <- 1234;dig <- 3;cha <- 4;
  # scr <- "Model_Hiera.stan";
  # source("Data_Hiera.R");


  if(PreciseLogLikelihood == FALSE  ){
    # scr <- "Model_Hiera.stan";
  scr <- system.file("extdata", "Model_Hiera.stan", package="BayesianFROC")

  }else{
    if(PreciseLogLikelihood == TRUE  ){
      # scr <- "Model_Hiera_TargetFormulation.stan";
  scr <-  system.file("extdata", "Model_Hiera_TargetFormulation.stan", package="BayesianFROC")

    } else{
      print("PreciseLogLikelihood is allowed only two choice; TRUE or FALSE.")
    }}

  data <-metadata_to_fit_MRMC(dataList)

  m<-data$m   ;S<-data$S;  NL<-data$NL;c<-data$c;q<-data$q;
  h<-data$h; f<-data$f;
  hh<-data$hh; hhN<-data$hhN;
  ff<-data$ff;ffN<-data$ffN;
  harray<-data$harray;    farray<-data$farray;
  hharray<-data$hharray;    ffarray<-data$ffarray;
  hharrayN<-data$hharrayN;    ffarrayN<-data$ffarrayN;

  C<-as.integer(data$C)
  M<-as.integer(data$M)
  N<-as.integer(data$N)
  Q<-as.integer(data$Q)


  if (summary==FALSE)message("\n* Now, the Hamiltonian Monte Carlo simulation is running...")


  rstan_options(auto_write = TRUE)

  scr <- rstan::stan_model(scr)# add

  # fit  <-  rstan::sampling(
  #                 object= scr, data=data,  verbose=F,
  #                  seed=see, chains=cha, warmup=war, iter=ite
  #                     , control = list(adapt_delta = 0.9999999,
  #                    max_treedepth = 15)#,init = initial
  # )

  if (summary==FALSE) {


    invisible(utils::capture.output(
      fit  <-  rstan::sampling(
        object= scr, data=data,  verbose=F,
        seed=see, chains=cha, warmup=war, iter=ite
        , control = list(adapt_delta = 0.9999999,
                         max_treedepth = 15)#,init = initial
      )
    ))
  }#if


  if (summary==TRUE) {

    fit  <-  rstan::sampling(
      object= scr, data=data,  verbose=F,
      seed=see, chains=cha, warmup=war, iter=ite
      , control = list(adapt_delta = 0.9999999,
                       max_treedepth = 15)#,init = initial
    )

  }#if


#   fit  <- stan(file=scr, model_name=scr, data=data, verbose=F,
#                seed=see, chains=cha, warmup=war,
#                iter=ite, control = list(adapt_delta = 0.9999999,
#                                         max_treedepth = 15)
# )

  # rstan::check_hmc_diagnostics(fit)

  convergence <- ConfirmConvergence(fit)
  if(convergence ==FALSE){message("\n* So, model has no mean, we have to finish a calculation !!\n")
    return(fit)}
  if(convergence ==TRUE){ if(summary==TRUE)         message(crayon::silver( "\n* We do not stop, since model cannot be said not converged.\n"))
                         }

    if(summary==TRUE) {
          # message("---------- Useage of the return value-------------------------  \n")
          message(crayon::silver( "\n * Using this return value which is S4 class generated by rstan::stan and another function in this package, you can draw FROC and AFROC curves.   \n"))
          message(crayon::silver( "\n * Using this return value, you can apply functions in the package rstan, e.g., rstan::traceplot().   \n"))
          # message("\n-----------------------------------------  \n")
          # message(" \n--------------------------------------------------  \n")
          if(PreciseLogLikelihood == FALSE  ){
          message(crayon::silver( "\n* WAIC did not caluculated, since log likelihood is not a precise value.\n"))
          # message(" \n--------------------------------------------------  \n")

        }else{
          if(PreciseLogLikelihood == TRUE  ){
            message(crayon::silver( "\n* WAIC was caluculated, since log likelihoodis is a precise value, i.e., the traget += statement are used in the stan file.\n"))
            # message(" \n--------------------------------------------------  \n")
             waic(fit)
          } else{
            print("PreciseLogLikelihood is allowed only two choice; TRUE or FALSE.")
          }}
    }# if summary ==TRUE


  fit.new.class <- methods::as(fit,"stanfitExtended")
  fit.new.class@metadata <-data
  fit.new.class@dataList <-dataList
  fit.new.class@studyDesign <-  "MRMC"
  fit.new.class@PreciseLogLikelihood    <-  PreciseLogLikelihood


  if(DrawCurve == TRUE  ){

    message(crayon::silver( "* Now, we draw the FROC and AFROC curves. \n"))
    message(crayon::silver( "* It takes time to draw FROC and AFROC curves. \n"))
    message(crayon::silver( "* Please wait ... . \n"))

    DrawCurves_MRMC(
                    StanS4class = fit.new.class
                    )


  }else{
            if(DrawCurve == FALSE  ){
              message(crayon::silver( "\n* We de not draw the FROC and AFROC curves. \n"))
              # message(" \n--------------------------------------------------  \n")

            } else{
              message(crayon::silver( "\n* DrawCurve is allowed only two choice; TRUE or FALSE. \n"))
            }
    }



  # is(fit,"stanfit")
  # getClass("stanfit")


#Change the S4 object (fit) from old class to new class

  if(PreciseLogLikelihood==TRUE) {fit.new.class@WAIC <- waic(fit,dig,summary=FALSE)}
  fit.new.class@convergence    <-  convergence


   fit.new.class@plotdataMRMC  <-  metadata_to_DrawCurve_MRMC(fit.new.class,mesh.for.drawing.curve = mesh.for.drawing.curve)


if(summary ==TRUE){
  # summary_AUC_comparison_MRMC(
  #   StanS4class=fit.new.class,
  #   significantLevel=significantLevel,
  #   dig=dig
  # )
  summarize_MRMC(fit.new.class,dig=dig)
}#if


   extractAUC(
     StanS4class=fit.new.class,
     summary=summary,
     dig=dig
   )
   if(summary ==FALSE){ message(crayon::silver( "\n* To see results, summary=TRUE \n"))}
check_rhat(fit)


rstan::check_hmc_diagnostics(fit)

if(summary ==TRUE){size_of_return_value(summary=summary,object =  fit.new.class)}


invisible(fit.new.class)




 }

==> BayesianFROC_0.1.2.tar.gz: BayesianFROC/R/fit_MRMC_test.R <==
#' @title  Fit and Draw the FROC models (curves)
#'
#'@inheritParams fit_Bayesian_FROC
#'@description  Fit and Draw the FROC models (curves).
#'
# sum(exp(rstan::extract(stan.MRMC)$lp__))/(10000-3000)
# devtools::use_package("base")# this will cause error, do not run!!
# devtools::use_package("rstan")
# devtools::use_package("knitr")
# devtools::use_package("readxl")
# devtools::use_package("openxlsx")
# devtools::use_package("xlsx")

# @importFrom base system.file
# devtools::document();help("fit_MRMC_test") # Confirm reflection



#' @export fit_MRMC_test

fit_MRMC_test<- function(
                      dataList,
                      DrawCurve = FALSE,
                      PreciseLogLikelihood = FALSE,
                      summary =TRUE,
                      mesh.for.drawing.curve=10000,
                      significantLevel = 0.7,
                      cha = 1,
                      war = floor(ite/5),
                      ite = 10000,
                      dig = 3,
                      see = 1234569){


  if ( is.null(dataList$m)||is.null(dataList$q)||is.null(dataList$c)) {
    return(message("Dataformat error.  Your data may be not multiple reader and multiple case,
                   but a single reader and a singlr modality case."))
  }


 if(summary==TRUE){ viewdata(dataList )} # I do not know, but this code is the availble only in the last part.

   # war <- 5000 ;ite <- 10000;see <- 1234;dig <- 3;cha <- 4;
  # scr <- "Model_Hiera.stan";
  # source("Data_Hiera.R");


  if(PreciseLogLikelihood == FALSE  ){
    # scr <- "Model_Hiera.stan";
  scr <- system.file("extdata", "Model_Hiera.stan", package="BayesianFROC")

  }else{
    if(PreciseLogLikelihood == TRUE  ){
      # scr <- "Model_Hiera_TargetFormulation.stan";
  scr <-  system.file("extdata", "Model_Hiera_TargetFormulation.stan", package="BayesianFROC")

    } else{
      print("PreciseLogLikelihood is allowed only two choice; TRUE or FALSE.")
    }}

  data <-metadata_to_fit_MRMC(dataList)

  m<-data$m   ;S<-data$S;  NL<-data$NL;c<-data$c;q<-data$q;
  h<-data$h; f<-data$f;
  hh<-data$hh; hhN<-data$hhN;
  ff<-data$ff;ffN<-data$ffN;
  harray<-data$harray;    farray<-data$farray;
  hharray<-data$hharray;    ffarray<-data$ffarray;
  hharrayN<-data$hharrayN;    ffarrayN<-data$ffarrayN;

  C<-as.integer(data$C)
  M<-as.integer(data$M)
  N<-as.integer(data$N)
  Q<-as.integer(data$Q)


  if (summary==FALSE)message("\n* Now, the Hamiltonian Monte Carlo simulation is running...")


  rstan_options(auto_write = TRUE)

  scr <- rstan::stan_model(scr)# add

  # fit  <-  rstan::sampling(
  #                 object= scr, data=data,  verbose=F,
  #                  seed=see, chains=cha, warmup=war, iter=ite
  #                     , control = list(adapt_delta = 0.9999999,
  #                    max_treedepth = 15)
  #,init = initial
  # )
  # initial <- initial_values_specification_for_stan_in_case_of_MRMC(dataList)
  if (summary==FALSE) {


    invisible(utils::capture.output(
      fit  <-  rstan::sampling(
        object= scr, data=data,  verbose=F,
        seed=see, chains=cha, warmup=war, iter=ite
        , control = list(adapt_delta = 0.9999999,
                         max_treedepth = 15)
        # ,init = initial
      )
    ))
  }#if


  if (summary==TRUE) {

    fit  <-  rstan::sampling(
      object= scr, data=data,  verbose=F,
      seed=see, chains=cha, warmup=war, iter=ite
      , control = list(adapt_delta = 0.9999999,
                       max_treedepth = 15)#,init = initial
    )

  }#if


#   fit  <- stan(file=scr, model_name=scr, data=data, verbose=F,
#                seed=see, chains=cha, warmup=war,
#                iter=ite, control = list(adapt_delta = 0.9999999,
#                                         max_treedepth = 15)
# )

  # rstan::check_hmc_diagnostics(fit)

  convergence <- ConfirmConvergence(fit)
  if(convergence ==FALSE){message("\n* So, model has no mean, we have to finish a calculation !!\n")
    return(fit)}
  if(convergence ==TRUE){ if(summary==TRUE)         message(crayon::silver( "\n* We do not stop, since model cannot be said not converged.\n"))
                         }

    if(summary==TRUE) {
          # message("---------- Useage of the return value-------------------------  \n")
          message(crayon::silver( "\n * Using this return value which is S4 class generated by rstan::stan and another function in this package, you can draw FROC and AFROC curves.   \n"))
          message(crayon::silver( "\n * Using this return value, you can apply functions in the package rstan, e.g., rstan::traceplot().   \n"))
          # message("\n-----------------------------------------  \n")
          # message(" \n--------------------------------------------------  \n")
          if(PreciseLogLikelihood == FALSE  ){
          message(crayon::silver( "\n* WAIC did not caluculated, since log likelihood is not a precise value.\n"))
          # message(" \n--------------------------------------------------  \n")

        }else{
          if(PreciseLogLikelihood == TRUE  ){
            message(crayon::silver( "\n* WAIC was caluculated, since log likelihoodis is a precise value, i.e., the traget += statement are used in the stan file.\n"))
            # message(" \n--------------------------------------------------  \n")
             waic(fit)
          } else{
            print("PreciseLogLikelihood is allowed only two choice; TRUE or FALSE.")
          }}
    }# if summary ==TRUE


  fit.new.class <- methods::as(fit,"stanfitExtended")
  fit.new.class@metadata <-data
  fit.new.class@dataList <-dataList
  fit.new.class@studyDesign <-  "MRMC"
  fit.new.class@PreciseLogLikelihood    <-  PreciseLogLikelihood


  if(DrawCurve == TRUE  ){

    message(crayon::silver( "* Now, we draw the FROC and AFROC curves. \n"))
    message(crayon::silver( "* It takes time to draw FROC and AFROC curves. \n"))
    message(crayon::silver( "* Please wait ... . \n"))

    DrawCurves_MRMC(
                    StanS4class = fit.new.class
                    )


  }else{
            if(DrawCurve == FALSE  ){
              message(crayon::silver( "\n* We de not draw the FROC and AFROC curves. \n"))
              # message(" \n--------------------------------------------------  \n")

            } else{
              message(crayon::silver( "\n* DrawCurve is allowed only two choice; TRUE or FALSE. \n"))
            }
    }



  # is(fit,"stanfit")
  # getClass("stanfit")


#Change the S4 object (fit) from old class to new class

  if(PreciseLogLikelihood==TRUE) {fit.new.class@WAIC <- waic(fit,dig,summary=FALSE)}
  fit.new.class@convergence    <-  convergence


   fit.new.class@plotdataMRMC  <-  metadata_to_DrawCurve_MRMC(fit.new.class,mesh.for.drawing.curve = mesh.for.drawing.curve)


if(summary ==TRUE){
  # summary_AUC_comparison_MRMC(
  #   StanS4class=fit.new.class,
  #   significantLevel=significantLevel,
  #   dig=dig
  # )
  summarize_MRMC(fit.new.class,dig=dig)
}#if


   extractAUC(
     StanS4class=fit.new.class,
     summary=summary,
     dig=dig
   )
   if(summary ==FALSE){ message(crayon::silver( "\n* To see results, summary=TRUE \n"))}
check_rhat(fit)


rstan::check_hmc_diagnostics(fit)

if(summary ==TRUE){size_of_return_value(summary=summary,object =  fit.new.class)}


invisible(fit.new.class)




 }
